===============
Target audience
===============

Who is the target audience of the ASpecD framework? Is it interesting for me?


Spectroscopists aiming at reproducibility
=========================================

The ASpecD framework addresses every scientist working with data (both, measured and calculated) on a daily base. As ASpecD is developed by an (experimental) spectroscopist, the focus is mainly on spectroscopy for the time being, although the underlying concepts should be sufficiently general to be useful in other context as well.


Motivation and general ideas
============================

The motivation and general idea behind the ASpecD framework is to ensure reproducibility and---as much as possible---replicability of data processing, starting from recording data and ending with their final (graphical) representation, e.g., in a peer-reviewed publication. This is done by mostly automatically creating a gap-less record of each processing step.

Every scientist should be well familiar with the concept of reproducibility and its importance for science in general. If you don't really care about reproducibility, you will probably have hard time using the ASpecD framework. Particularly those aspects of the framework ensuring reproducibility may impair your personal freedom of doing things your way. If, however, you do care about reproducibility and are looking for a system that helps you to achieve this goal, ASpecD may well be interesting for you.
